pub struct Gcd<'a> { /* private fields */ }Expand description
Given BinaryBundles a and b, output GCD(a, b).
Implementations
Sourceimpl<'a> Gcd<'a>
impl<'a> Gcd<'a>
Sourcepub fn new(upper_bound: usize) -> Self
pub fn new(upper_bound: usize) -> Self
Create a new Gcd circuit using a fixed upper bound.
Since the circuit needs to be oblivious, we cannot terminate the GCD
algorithm by conditioning on the values of a or b as is the case in
the “standard” version of GCD. Instead, we rely on an upper bound on the
number of iterations we know the algorithm will terminate by. The
Euclidean algorithm based on subtractions will take no more than N steps
where N is the larger of the two numbers we are computing the GCD for.